/* 
--  WELCOME to example02 for the Super DMX Shield (Version 1 C)
--  The example uses the DmxSimple Library which was deceloped by tinkerit
--  and can be found here: http://code.google.com/p/tinkerit/
--  Questions regarding the library? http://groups.google.com/group/dmxsimple   
--  Questions regarding the Super DMX Shield? email d@plankman.com

-- Your SUPER DMX SHIELD has the following features:
-- 1.  DMX output on digital pin 12
-- 2.  Digital INPUT (Switch) on digital pin 8
-- 3.  ANALOG input on A0 BUT PLEASE NOTE: 
--        To use this, you have to connect the V+ to either 3.3V or 5V
--        Its easy though, if you find the VSEL / A0 pin, 
--        Then simply make a connection from that to whichever voltage your analog sensor needs!

-- This example steps through 16 channels of a DMX system.  
--  As it steps to the latest position, it sets its power (brightness) to be maximum.  
--  All the rest of the channels slowly dim to their lowest power.

-- More info:   www.technologywillsaveus.com
                www.hirschandmann.com/DMX
*/

#include <DmxSimple.h>

long timer;              // simple timer variable to help us create a framerate
long oldTime = 0;        // used for the framerate
long currentTime = 0;    // used for the framerate

int channels[16];            // Array to hold the values for each of our DMX channels
int currentChan;             // A variable to act as a marker so we can step through the channel array

void setup() {
  Serial.begin(9600);        // connect to the serial port
  Serial.println("STARTED!"); 

  DmxSimple.usePin(12);              // Enable DMX library to use the SUPER DMX SHIELD data pin
  DmxSimple.maxChannel(16);          // Let the library know how many DMX channels it should be addressing (its addressable DMX universe size)
}

void loop() 
{
  // work out frameRate
  // This code chunk simply increments the timer every 1 milli second.  
  // If we want the lights to be updated 30 FPS, then it should be updated every 1000/30 = 32 milliseconds
  currentTime = millis();
  if (currentTime - oldTime >= 1) 
  {
    oldTime = currentTime;
    timer++;
  }
  
  
  if (timer%32 == 0) {               // every 32 milliseconds, decrement all the DMX channel values
    for (int i = 0; i<16; i++)       // loop through all the channels here
    {  
      if (channels[i] > 0) channels[i] -= 1;    // if the channels are not already at 0, then decrement
      DmxSimple.write(i,channels[i]);           // add the new channel value to the DMX library's array
    }
  }
  
  if (timer >= 128)        // approximately every 1/8th of a second, move the position of the brightest channel forward
  {                        // use 128 here because then the modulo (%) of 32 above will be cleanly divisible 
    timer = 0;             // reset the timer otherwise it will happen repeatedly
    currentChan++;          // increment the brightest channel's position
    if (currentChan >= 16) currentChan = 0;       // wrap the position 
    channels[currentChan] = 255;                  // set its new brightness value in the array
  } 
}



